# Changelog

## [0.2.0] - 2023-06-11

---

### Features

- added removeEmpty function

### Chore

- added doctest
- added tox
- update docstrings
- fixed usage examples

## [0.1.5] - 2022-08-14

---

### Features

- descriptions to functions is added
- intersectionHash function is added
- unset function is added

### Bug Fixes

- intersection function wrong results with more then 2 args

### Chore

- typings updates
- uniqHash preserves order

## [0.1.4] - 2022-08-14

---

### skipped

## [0.1.3] - 2022-01-08

---

### Features

- chunk function works faster
